<?php
/*
 Plugin Name: WP JQuery Timelinr
 Plugin URI: http://www.csslab.cl/2011/08/18/jquery-timelinr/
 Description: This simple plugin helps you to give more life to the boring timelines. Supports horizontal and vertical layouts, and you can specify parameters for most attributes: speed, transparency, etc.
 Version: 0.1
 Author: Broobe
 Author URI: http://www.broobe.com
 Text Domain: wp-jquery-timelinr

 Copyright 2012  broobe  (email : info@broobe.com)

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License, version 2, as
 published by the Free Software Foundation.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Broobe, Nicolas Avellaneda 953, Castelar, Buenos Aires (011) 5555-5952 AR
 */

if (!class_exists('jqueryTimelinrLoad')) {

	class jqueryTimelinrLoad {
		public $options;
		private $demo = FALSE;

		public function __construct() {
			$this -> loadConstants();
			$this -> loadDependencies();
			
			// Start this plug-in once all other plugins are fully loaded
			add_action('plugins_loaded', array(&$this, 'start'));

		}

		public function start() {
			load_plugin_textdomain('wp-jquery-timelinr', false, JQTL_DIR_NAME . '/lang');
			
			// Register Common scripts
			add_action( 'init', array(&$this, 'registerScripts' ) );

			if ( is_admin() ){
				add_action( 'init', array(&$this, 'adminActions') );
			}
			else{
				add_action('wp_print_scripts', array(&$this, 'loadScripts'));
				add_action('wp_print_styles', array(&$this, 'loadStyles'));
			}
		}

		private function loadConstants() {
			define('JQTL_CURRENT_VERSION', '1.0');
			define('JQTL_DIR_NAME', plugin_basename(dirname(__FILE__)));
			define('JQTL_BASE_NAME', plugin_basename(__FILE__));
			define('JQTL_BASE_PATH', WP_PLUGIN_DIR . '/' . JQTL_DIR_NAME);
			define('JQTL_BASE_URL', WP_PLUGIN_URL . '/' . JQTL_DIR_NAME);
		}
		
		/**
		 * Called when activating WP JQuery Timelinr via the activation hook.
		 * @return null
		 */
		public function activate()
		{
		}
		
		/**
		 * Called when deactivating WP JQuery Timelinr via the deactivation hook.
		 * @return null
		 */
		public function deactivate()
		{	
		}
		
		private function loadDependencies(){
			add_shortcode('timelinr', array(&$this, 'shortcode'));
		}	
		
		/**
		 * Register the external JS libraries that may be enqueued in either the frontend or admin.
		 * 
		 * @return NULL
		 */
		public function registerScripts()
		{
			if (!wp_script_is( 'jquery', 'registered' )){
		    	wp_register_script( 'jquery' );
		    }
			
			wp_deregister_script('jquery.timelinr');
			wp_register_script('jquery.timelinr', JQTL_BASE_URL . '/assets/js/jquery.timelinr-0.9.51.js', array( 'jquery' ));
		}

		/**
		 * Called when running the wp_print_scripts action.
		 * @return null
		 */
		public function loadScripts() {
		    if (!is_admin()) {
				if (!wp_script_is( 'jquery', 'queue' )){
			    	wp_enqueue_script( 'jquery' );
			    }
				wp_enqueue_script('jquery.timelinr', JQTL_BASE_URL . '/assets/js/jquery.timelinr-0.9.51.js', array( 'jquery' ));
			}
		}

		/**
		 * Called when running the wp_print_styles action.
		 * @return null
		 */
		public function loadStyles() {
 		}
		
		public function adminActions() {
			//Custom Post Type TimeLine
			$labels = array(
			  'name' => _x('Timeline', 'post type general name', 'wp-jquery-timelinr'),
			  'singular_name' => _x('Timeline', 'post type singular name', 'wp-jquery-timelinr'),
			  'add_new' => _x('Add New', 'slide', 'wp-jquery-timelinr'),
			  'add_new_item' => __('Add New Event', 'wp-jquery-timelinr'),
			  'edit_item' => __('Edit Event', 'wp-jquery-timelinr'),
			  'new_item' => __('New Event', 'wp-jquery-timelinr'),
			  'view_item' => __('View Event', 'wp-jquery-timelinr'),
			  'search_items' => __('Search Event', 'wp-jquery-timelinr'),
			  'not_found' =>  __('No timeline items found.', 'wp-jquery-timelinr'),
			  'not_found_in_trash' => __('No timeline items found in Trash.', 'wp-jquery-timelinr'), 
			  'parent_item_colon' => ''
			);
			$args = array(
			  'labels' => $labels,
			  'public' => true,
			  'publicly_queryable' => true,
			  'show_ui' => true, 
			  'query_var' => true, 
			  'capability_type' => 'post', 
			  'menu_position' => null,
			  'rewrite' => array('slug'=>'fecha','with_front'=>false),
			  'supports' => array('title','editor','thumbnail')
			); 
			register_post_type('timelinr',$args);
			
			
			//Custom Field Date
			add_action("admin_init", "timelinr_meta_box");     
			function timelinr_meta_box(){    
			    add_meta_box("timelineInfo-meta", __('Year', 'wp-jquery-timelinr'), "timelinr_meta_options", "timelinr", "side", "low");    
			}    
			  
			function timelinr_meta_options(){    
		        global $post;    
		        if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) return $post_id;  
		        $custom = get_post_custom($post->ID);    
		        $link = $custom["timelineDate"][0];?>
				
				<select name="timelineDate" id="timelineDate">
					<?php for($i=date('Y'); $i>1899; $i--) :
						$selected = '';
						if ($link == $i) $selected = ' selected="selected"';?>
						<option value=<?=$i.$selected?>><?=$i?></option>
				 	<?php endfor;?>
				</select><?php    
			}
			
			add_action('save_post', 'save_timelinr_date');   
			function save_timelinr_date(){    
			    global $post;    
			    if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ){   
			        return $post_id;  
			    }else{
			        update_post_meta($post->ID, "timelineDate", $_POST["timelineDate"]);   
			    }   
			} 
			
			//Customizing Admin Columns
			add_filter("manage_edit-timelinr_columns", "set_custom_edit_timelinr_columns");     
			function set_custom_edit_timelinr_columns($columns){    
				$columns = array(    
					"cb" => "<input type=\"checkbox\" />",    
					"title" => __('Event', 'wp-jquery-timelinr'),    
					"year" => __('Year', 'wp-jquery-timelinr')
				);    
				return $columns;    
			}    
			  
			add_action("manage_timelinr_posts_custom_column",  "timelinr_custom_column");   
			    
			function timelinr_custom_column($column){    
			        global $post;    
			        switch ($column)    
			        {      
			            case "year":    
			                $custom = get_post_custom();    
			                echo $custom["timelineDate"][0];    
			                break; 
			        }    
			}    
		}

		public function shortcode($atts, $content = NULL) {
			global $wpdb;
			
			$pairs = array(
					'orientation' => 'horizontal',
					'startat' => 1,
					'arrowkeys' => 'false',
					'autoplay' => 'false',
					'autoplaydirection' => 'backward',
					'autoplaypause' => 2000
			);
			$atts = shortcode_atts($pairs, $atts );
			
			if ( $atts['orientation'] == 'horizontal' ){
				wp_enqueue_style('timelinr-style', JQTL_BASE_URL . '/assets/css/style.css', '', JQTL_CURRENT_VERSION );
			} else {
				wp_enqueue_style('timelinr-style_v', JQTL_BASE_URL . '/assets/css/style_v.css', '', JQTL_CURRENT_VERSION );
			}
			
			ob_start();
			include (JQTL_BASE_PATH . '/includes/template.php');
			$out = ob_get_contents();
			ob_end_clean();
			
			return $out;
		}
	}

	/*
	 * Initiate the plug-in.
	 */
	global $jqueryTimelinrLoad;
	$jqueryTimelinrLoad = new jqueryTimelinrLoad();
}
?>